<!-- 地区设备运行情况 -->
<template>
    <div class="data-overview">
        <div class="header">
            <div class="header-title">地区设备运行情况</div>
        </div>

        <div ref="chartRef" style="width: 100%; min-height: 800px"></div>
    </div>
</template>
<script lang="ts" name="DeviceRunningStatus" setup>
import { useMenuStore } from '@/store/menu';
import * as echarts from 'echarts';

const chartRef = ref<Record<string, any>>({});
const menu = useMenuStore();
let myChart: any = null;

const handleOptions = (x = [], y = []) => {
    const chart: any = chartRef.value;
    if (chart) {
        myChart = echarts.init(chart);
        const options = {
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    // Use axis to trigger tooltip
                    type: 'shadow', // 'shadow' as default; can also be 'line' or 'shadow'
                },
            },
            legend: {
                top: "20",
                right: "20"
            },
            grid: {
                left: '3%',
                right: '4%',
                bottom: '3%',
                containLabel: true,
            },
            xAxis: {
                type: 'value',
            },
            yAxis: {
                type: 'category',
                data: [
                    'Mon',
                    'Tue',
                    'Wed',
                    'Thu',
                    'Fri',
                    'Sat',
                    'Mon',
                    'Tue',
                    'Wed',
                    'Thu',
                    'Fri',
                    'Mon',
                    'Sun',
                ],
            },
            series: [
                {
                    name: 'Direct',
                    type: 'bar',
                    stack: 'total',
                    label: {
                        show: true,
                    },
                    barWidth: '30',
                    emphasis: {
                        focus: 'series',
                    },
                    data: [
                        320, 302, 301, 334, 390, 330, 320, 320, 302, 301, 334,
                        390, 330,
                    ],
                },
                {
                    name: 'Mail Ad',
                    type: 'bar',
                    stack: 'total',
                    label: {
                        show: true,
                    },
                    barWidth: '30',
                    emphasis: {
                        focus: 'series',
                    },
                    data: [
                        120, 132, 101, 134, 320, 302, 301, 334, 390, 330, 90,
                        230, 210,
                    ],
                },
                {
                    name: 'Affiliate Ad',
                    type: 'bar',
                    stack: 'total',
                    label: {
                        show: true,
                    },
                    barWidth: '30',
                    emphasis: {
                        focus: 'series',
                    },
                    data: [
                        220, 182, 320, 302, 301, 334, 390, 330, 191, 234, 290,
                        330, 310,
                    ],
                },
            ],
        };
        nextTick(() => {
            myChart.setOption(options);
            window.addEventListener('resize', function () {
                myChart.resize();
            });
        });
    }
};

watch(
    () => menu.collapsed,
    (newX) => {
        setTimeout(() => {
            myChart.resize();
        }, 300);
    },
);

onMounted(() => {
    handleOptions();
});
</script>
<style scoped lang="less">
.data-overview {
    padding: 16px;
    .header {
        display: flex;
        align-items: center;
        justify-content: space-between;
        .header-title {
            border-left: 3px solid #3468ff;
            padding-left: 8px;
            font-size: 16px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            color: #333333;
            line-height: 23px;
        }
    }
}
</style>
